package echo;
import java.rmi.*;
import java.rmi.server.*;
public class EchoClient {
	public static void main (String args[]) {
		
		int i; // iterator
		final int ITERATIONS = 10; // iterations
		
		/* create and install security manager
		 * to allow for dynamic load of remote object stub */
		 if (System.getSecurityManager() == null) 
		 	System.setSecurityManager ( new RMISecurityManager() );
		 	
		 try {
		 	/* recall that the Client object is invoked with 2 arguments:
		 	 * 1: <host>:end-point
		 	 * 2: message_string */
		 	 System.out.println ("EchoClient ready!");
		 	 final String URL = "rmi://" + args[0] + "/Echo";
		 	 System.out.println ("Looking up remote object "+URL+" ...");
		 	 
		 	 // Look up an implementation of the Echo remote object
		 	 Echo echo = (Echo) Naming.lookup (URL);
		 	 
		 	 String toMsg = (String) args[1];
		 	 
		 	 for (i = 1; i < ITERATIONS; i++) {
		 	 	toMsg = toMsg + "-" + i;
		 	 	System.out.println("Message "+i+" to Echo: ["+toMsg+"]");
		 	 	
		 	 	// Call up remote method
		 	 	String fromMsg = echo.call (toMsg);
		 	 	
		 	 	System.out.println ("Message from Echo: \n\t"+fromMsg+"\n");
		 	 	
		 	 	Thread.sleep (2000);
		 	 	}
		 	 } catch (Exception e) {
		 	 	System.out.println ("Exception in EchoClient: "+e.getMessage());
		 	 	e.printStackTrace();
		 	 	}
		 }
}
